package Qt::Gui::QErrorMessage;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QErrorMessage
# file     : QtGui/qerrormessage.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QDialog/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QErrorMessage

=head1 PUBLIC METHODS

=over

=item   QErrorMessage(QWidget * parent)

=item   QErrorMessage(QWidget * parent = 0)

=item   ~QErrorMessage()

=item  static QErrorMessage * qtHandler()

=item  void showMessage(const QString & message)

=item  void showMessage(const QString & message, const QString & type)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
